@@ -1,6 +1,6 @@
 package Pcore::App::Nginx;
 
-use Pcore qw[-cli -class];
+use Pcore qw[-class];
 
 extends qw[Pcore::App::Alien];
 
@@ -15,51 +15,39 @@ our $CFG = {
     },
 };
 
-sub _build_nginx_ver {
-    my $self = shift;
+# CLI
+sub cli_name ($self) {
+    return 'nginx';
+}
 
-    return $self->cfg->{NGINX}->{NGINX_VER} || $DIST->{NGINX}->{NGINX_VER};
+sub _build_nginx_ver ($self) {
+    return $self->cfg->{NGINX}->{NGINX_VER} || $PROC->{CFG}->{NGINX}->{NGINX_VER};
 }
 
 # APP
-around _build_cfg => sub {
-    my $orig = shift;
-    my $self = shift;
-
+around _build_cfg => sub ( $orig, $self ) {
     return P->hash->merge( $self->$orig, $CFG );
 };
 
-around _create_local_cfg => sub {
-    my $orig = shift;
-    my $self = shift;
-
+around _create_local_cfg => sub ( $orig, $self ) {
     my $local_cfg = {};
 
     return P->hash->merge( $self->$orig, $CFG, $local_cfg );
 };
 
-sub _build_alien_dir {
-    my $self = shift;
-
+sub _build_alien_dir ($self) {
     return $self->app_dir . 'nginx-' . $self->nginx_ver . q[/];
 }
 
-sub _build_alien_bin_path {
-    my $self = shift;
-
+sub _build_alien_bin_path ($self) {
     return $self->alien_dir . 'sbin/nginx';
 }
 
-sub _build_alien_cfg_path {
-    my $self = shift;
-
+sub _build_alien_cfg_path ($self) {
     return $self->app_dir . 'nginx.conf';
 }
 
-around app_build => sub {
-    my $orig = shift;
-    my $self = shift;
-
+around app_build => sub ( $orig, $self ) {
     $self->$orig;
 
     if ( -d $self->alien_dir ) {
@@ -128,7 +116,7 @@ around app_build => sub {
 
         # pcre
         P->ua->get(
-            qq[http://nchc.dl.sourceforge.net/project/pcre/pcre/$DIST->{NGINX}->{PCRE_VER}/pcre-$DIST->{NGINX}->{PCRE_VER}.tar.gz],
+            qq[http://nchc.dl.sourceforge.net/project/pcre/pcre/$PROC->{CFG}->{NGINX}->{PCRE_VER}/pcre-$PROC->{CFG}->{NGINX}->{PCRE_VER}.tar.gz],
             buf_size    => 1,
             blocking    => $cv,
             on_progress => 1,
@@ -177,7 +165,7 @@ around app_build => sub {
                 '--with-http_sub_module',
                 '--with-http_gzip_static_module',
                 '--with-http_perl_module',
-                '--with-pcre=' . $build_dir . 'pcre-' . $DIST->{NGINX}->{PCRE_VER},
+                '--with-pcre=' . $build_dir . 'pcre-' . $PROC->{CFG}->{NGINX}->{PCRE_VER},
                 '--with-pcre-jit',
                 map { '--add-module=' . $build_dir . $module->{$_}->{path} } grep { $module->{$_}->{enabled} } keys $module->%*,
             );
@@ -206,19 +194,13 @@ around app_build => sub {
     return;
 };
 
-around app_deploy => sub {
-    my $orig = shift;
-    my $self = shift;
-
+around app_deploy => sub ( $orig, $self ) {
     $self->$orig;
 
     return;
 };
 
-around app_test => sub {
-    my $orig = shift;
-    my $self = shift;
-
+around app_test => sub ( $orig, $self ) {
     $self->$orig;
 
     say 'Config test';
@@ -239,9 +221,7 @@ around app_test => sub {
     return;
 };
 
-sub generate_alien_cfg {
-    my $self = shift;
-
+sub generate_alien_cfg ($self) {
     my $cfg;
 
     # TODO PCORE-19
@@ -264,8 +244,7 @@ sub generate_alien_cfg {
     return;
 }
 
-sub master_proc {
-    my $self = shift;
+sub master_proc ($self) {
 
     # плавное завершение
     $SIG->{QUIT} = AE::signal QUIT => sub {
@@ -307,9 +286,7 @@ sub master_proc {
     return;
 }
 
-sub alien_proc {
-    my $self = shift;
-
+sub alien_proc ($self) {
     $self->generate_alien_cfg;
 
     exec $self->alien_bin_path, q[-c], $self->alien_cfg_path or die;
@@ -322,7 +299,7 @@ sub alien_proc {
 ## ┌──────┬──────────────────────┬────────────────────────────────────────────────────────────────────────────────────────────────────────────────┐
 ## │ Sev. │ Lines                │ Policy                                                                                                         │
 ## ╞══════╪══════════════════════╪════════════════════════════════════════════════════════════════════════════════════════════════════════════════╡
-## │    3 │ 143, 182             │ References::ProhibitDoubleSigils - Double-sigil dereference                                                    │
+## │    3 │ 131, 170             │ References::ProhibitDoubleSigils - Double-sigil dereference                                                    │
 ## └──────┴──────────────────────┴────────────────────────────────────────────────────────────────────────────────────────────────────────────────┘
 ##
 ## -----SOURCE FILTER LOG END-----
